==> pan-0.6.5.tar.bz2: pan-0.6.5/pan/group.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __GROUPS_H__
#define __GROUPS_H__

enum {
	GROUP_ALL          = 0,
	GROUP_SUBSCRIBED   = 1<<1,
	GROUP_NEW          = 1<<2
};

struct AHDB; /* advance declaration of article header db */ 

typedef struct _group_data group_data;
struct _group_data
{
	gchar*  name;	     /* alt.what.is.my.name */
	gint    flags;	     /* ??? */
};

extern int group_mode;
extern GtkWidget *groups_clist_menu;

GtkWidget* create_articlelist_clist (void);
void open_group_file (FILE *);
void load_groups_file	(void);
void load_group_list	(void);
gint compare_group_data (group_data *, group_data *);
void check_new_group_list_for_newness ( GSList* list );
void choose_download_dialog (group_data *);
void group_free			(group_data *gdata);
void get_all_groups		(void);
void unsubscribe_from_selected_cb (void);
void subscribe_to_selected_cb (void);
void download_selected_groups_cb (void);
void download_selected_groups_new_cb (void);
void group_empty (group_data *gdata);
void group_empty_cb (GnomeDialog *dialog, int button_number, gpointer gdata);
void group_empty_dialog (group_data *gdata);
void click_groups_column_cb (GtkCList *clist, int n);
void add_group_to_clist (group_data *gdata);
void add_subscribed_group_to_clist (group_data* gdata);
void add_new_group_to_clist (group_data* gdata);
void group_dialog_clicked_cb (GnomeDialog* dialog, int num);
void choose_download_dialog_clicked_cb (GnomeDialog* dialog, int button_number, gpointer gdata);
void group_unload (group_data *gdata);
void grouplist_process_selected (int type);
group_data* group_copy (group_data *src);


//=============

int group_get_attrib_i	(const group_data *, const char *);
void group_set_attrib_i	(const group_data *, const char *, int);
void group_add_attrib_i (const group_data *, const char *, int);
void group_set_attrib_string (const group_data *gdata, const char *attrib, const char *value);
gchar* group_get_attrib_string (const group_data *gdata, const char *attrib);

//=============

void group_set_active_group ( group_data* );

#endif /* __GROUPS_H__ */

==> pan-0.6.6.tar.bz2: pan-0.6.6/pan/group.h <==
/* Pan -
 *
 * Copyright (C) 1999 Matt Eagleson (e.Messiah@superpimp.org)
 *
 * Authors: Matt Eagleson <e.Messiah@superpimp.org>
 *          Charles Kerr <charles@skywalker.ecn.ou.edu>
 *          Jason Leach <leach@wam.umd.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef __GROUPS_H__
#define __GROUPS_H__

enum {
	GROUP_ALL          = (1<<0),
	GROUP_SUBSCRIBED   = (1<<1),
	GROUP_NEW          = (1<<2)
};

//struct AHDB; /* advance declaration of article header db */ 

typedef struct
{
	gchar*  name;	     /* alt.what.is.my.name */
	gint    flags;	     /* new, subscribed */
}
group_data;

extern int group_mode;
extern GtkWidget *groups_clist_menu;

GtkWidget* create_articlelist_clist (void);
gint compare_group_data (group_data *, group_data *);
void check_new_group_list_for_newness ( GSList* list );
void choose_download_dialog (group_data *);
void group_free			(group_data *gdata);
void get_all_groups		(void);
void get_new_groups		(void);
void group_empty (group_data *gdata);
void group_empty_cb (GnomeDialog *dialog, int button_number, gpointer gdata);
void group_empty_dialog (group_data *gdata);
void click_groups_column_cb (GtkCList *clist, int n);
void group_dialog_clicked_cb (GnomeDialog* dialog, int num);
void choose_download_dialog_clicked_cb (GnomeDialog* dialog, int button_number, gpointer gdata);
void group_unload (group_data *gdata);
group_data* group_copy (group_data *src);

//=============

void add_group_to_clist (group_data *gdata);
void add_group_to_clist_if_match(group_data*, gint flag_mask); 
void add_group_to_clist_if_match_gfunc(gpointer, gpointer);

//=============

int group_get_attrib_i	(const group_data *, const char *);
void group_set_attrib_i	(const group_data *, const char *, int);
void group_add_attrib_i (const group_data *, const char *, int);
void group_set_attrib_string (const group_data *gdata, const char *attrib, const char *value);
gchar* group_get_attrib_string (const group_data *gdata, const char *attrib);

//=============

void group_set_active_group ( group_data* );

#endif /* __GROUPS_H__ */
